import * as React from 'react';
import React__default, { ReactNode, FC, ReactElement } from 'react';
import { Location, URLSearchParamsInit, To, NavigateOptions, BrowserRouterProps, RouteProps as RouteProps$1, Path, LinkProps, NavigateFunction } from 'react-router-dom';
import { OperationVariables, TypedDocumentNode, QueryHookOptions, MutationHookOptions, ApolloQueryResult, QueryResult, DocumentNode as DocumentNode$1, ApolloClient, DefaultContext, ApolloCache, MutationFunctionOptions, FetchResult, MutationResult } from '@apollo/client';
import { I18nProviderProps } from 'ca-i18n';
export * from 'ca-i18n';
import { DocumentNode } from 'graphql';
import { BoxProps, TableProps, TableHeadProps, TableBodyProps, TableRowProps, TableCellProps, FlexProps, StackProps, ButtonProps, MenuButtonProps, UseDisclosureReturn, TextProps, ColorProps, ThemingProps, ChakraProps, InputProps as InputProps$1, FormLabelProps, ComponentWithAs, SelectProps, UseDisclosureProps, InputGroupProps, IconButtonProps, As, DrawerProps, ModalBodyProps, ModalHeaderProps, ModalProps } from '@chakra-ui/react';
import { NestedKeyOf, CAFieldProps, CAInputProps } from 'ca-system';
export * from 'ca-system';
import * as framer_motion from 'framer-motion';
import * as react_jsx_runtime from 'react/jsx-runtime';
import Fields from 'gql-query-builder/build/Fields';
import * as react_hook_form from 'react-hook-form';
import { UseFormRegister, UseFormUnregister, Control, FieldValues } from 'react-hook-form';
import { UseComboboxProps } from 'downshift';
import { IconProps } from '@chakra-ui/icons';
import { Locale } from 'date-fns';
import { DatetimepickerProps } from 'react-datetime';
import { Renderer, CellProps, HeaderProps, Column, TableInstance, Row } from 'react-table';
import * as recoil from 'recoil';
import { QueryParamConfig } from 'serialize-query-params';

interface DefaultUserIdentity {
    id: string;
    email: string;
    fullName: string;
    avatarUrl?: string;
    [prop: string]: any;
}
interface AuthProvider<LoginParams = Record<string, any>, UserIdentity = DefaultUserIdentity> {
    init: () => void;
    login: (params: LoginParams) => Promise<void>;
    checkError: (error: {
        status?: number;
    }) => Promise<void>;
    checkAuth: () => Promise<void>;
    logout: () => Promise<void>;
    getIdentity: () => Promise<UserIdentity>;
}

interface ClassType<T> extends Function {
    new (...args: any[]): T;
}

declare enum OffsetSortDirection {
    ASC = "ASC",
    DESC = "DESC"
}
declare type OffsetSortType<T extends Record<string, any>> = Record<keyof T, OffsetSortDirection>;

declare type PageLayoutProps = {
    title?: ReactNode;
    topToolbar?: ReactNode;
    renderingInModal?: boolean;
} & BoxProps;
declare const PageLayout: FC<PageLayoutProps>;

declare type PaginationMode$1 = 'offset' | 'cursor';
declare type ListProps<TQuery = Record<string, any>, TItem extends Record<string, any> = Record<string, any>, ListTData = any, ListTVariables = OperationVariables, DeleteTData = any, DeleteTVariables = OperationVariables> = {
    paginationMode?: PaginationMode$1;
    resource?: string;
    basePath?: string;
    /**
     * @deprecated
     * use defaultSort instead
     */
    defaultSorting?: OffsetSortType<TItem>;
    /**
     * offset based pagination default sort
     */
    defaultSort?: OffsetSortType<TItem>;
    /**
     * cursor based pagination default sort
     */
    defaultSortBy?: keyof TItem;
    defaultFilters?: Record<string, any>;
    filtersComponent?: React__default.ReactNode;
    toolbarComponent?: React__default.ReactNode;
    query: keyof TQuery | (DocumentNode | TypedDocumentNode<ListTData, ListTVariables>);
    queryOptions?: QueryHookOptions<ListTData, ListTVariables>;
    listStrategy?: Partial<ListStrategy>;
    deleteItemMutation?: DocumentNode | TypedDocumentNode<DeleteTData, DeleteTVariables>;
    deleteItemMutationOptions?: MutationHookOptions<DeleteTData, DeleteTVariables>;
    showMoreMenu?: boolean;
    showMoreMenuEdit?: boolean;
    showMoreMenuDelete?: boolean;
    hasDelete?: boolean;
    hasEdit?: boolean;
    hasCreate?: boolean;
    hasShow?: boolean;
    hasList?: boolean;
    children?: React__default.ReactNode;
    layout?: ReactElement<PageLayoutProps, any>;
    fields?: NestedKeyOf<Required<TItem>>[];
    refetchOnDefaultFiltersChange?: boolean;
    defaultPerPage?: number;
} & Pick<PageLayoutProps, 'title'>;

declare const removeListProps: (props: ListProps) => any;

interface RouteAvailability {
    hasDelete?: boolean;
    hasEdit?: boolean;
    hasCreate?: boolean;
    hasShow?: boolean;
    hasList?: boolean;
}

declare const ADMIN_STATE_KEY = "adminState";
declare const registeredIcons: Record<string, React__default.ReactNode>;
interface RegisteredResources {
    [key: string]: RouteAvailability & {
        iconName: string;
    };
}
interface AdminState {
    registeredResources: RegisteredResources;
    initialized: boolean;
}
declare const adminState: recoil.RecoilState<AdminState>;
declare const useAdminState: () => [AdminState, recoil.SetterOrUpdater<AdminState>];
declare const useAdminStateValue: () => AdminState;
declare const useSetAdminState: () => recoil.SetterOrUpdater<AdminState>;
declare const useResetAdminState: () => recoil.Resetter;

/**
 * This hook initialize the Admin App.
 * IMPORTANT! Don't use this hook more than once
 *
 * @param {React.ReactNode} children - children must be one or more Resources
 * @param {GlobalStrategy} strategy - The AuthProvider used to manage user authentication
 * @param {AuthProvider} authProvider - The AuthProvider used to manage user authentication
 */
declare const useAdminCore: ({ children, authProvider, strategy, }: AdminCoreProps) => {
    childrenCount: number;
    initialized: boolean;
    background?: Location | undefined;
    location: Location;
};

declare const useGetResourceLabel: () => (resource: string, count?: number) => string;

declare const TOKEN_GLOBAL_STRATEGY = "chakra-admin_GlobalStrategy";
declare type SetGlobalStrategyFunction = (newValue: ClassType<GlobalStrategy> | undefined) => void;
declare const useGlobalStrategy: () => GlobalStrategy | undefined;
declare const useSetGlobalStrategy: () => SetGlobalStrategyFunction;

declare const VERSION_STATE_KEY = "versionState";
declare const versionState: recoil.RecoilState<number>;
declare const useVersionState: () => [number, recoil.SetterOrUpdater<number>];
declare const useVersionStateValue: () => number;
declare const useSetVersionState: () => recoil.SetterOrUpdater<number>;
declare const useResetVersionState: () => recoil.Resetter;
declare const useVersion: () => () => void;

declare const DEFAULT_PER_PAGE = 20;
declare const QP_PER_PAGE = "l";
declare const QP_PAGE = "p";
declare const QP_AFTER = "a";
declare const QP_BEFORE = "b";
declare const QP_FIRST = "f";
declare const QP_LAST = "l";
declare const QP_REVERT = "r";
declare const QP_SORT_BY = "s";
declare const QP_SORT_PREFIX = "s_";
declare const QP_FILTERS_PREFIX = "f_";
declare type BaseListPagination = {
    paginationMode: PaginationMode$1;
    pageCount?: number;
    total?: number;
};
declare type OffsetOnPageChangeParams = {
    page: number;
    perPage: number;
};
declare type OffsetOnPageChange = (params: OffsetOnPageChangeParams) => void;
declare type CursorOnPageChangeParams = {
    after?: string;
    before?: string;
    first?: number;
    last?: number;
    revert?: boolean;
    sortBy?: string;
};
declare type CursorOnPageChange = (params: CursorOnPageChangeParams) => void;
declare type OnPageChangeParams = OffsetOnPageChangeParams | CursorOnPageChangeParams;
declare type OnPageChange = OffsetOnPageChange | CursorOnPageChange;
declare type OffsetOnSortChange<TItem extends Record<string, any> = Record<string, any>> = (sort: OffsetSortType<TItem>) => void;
declare type CursorsOnSortChangeParams<TItem extends Record<string, any> = Record<string, any>> = {
    sortBy?: keyof TItem | string;
    revert?: boolean;
    first?: number;
    last?: number;
};
declare type CursorOnSortChange<TItem extends Record<string, any> = Record<string, any>> = (sort: CursorsOnSortChangeParams<TItem>) => void;
declare type OnSortChange = OffsetOnSortChange | CursorOnSortChange;
declare type OffsetPagination = BaseListPagination & {
    paginationMode: 'offset';
    page: number;
    perPage: number;
    onPageChange: OffsetOnPageChange;
    currentSort: OffsetSortType<any>;
    onSortChange: OffsetOnSortChange;
};
declare type CursorPagination = BaseListPagination & {
    paginationMode: 'cursor';
    after?: string;
    before?: string;
    first?: number;
    last?: number;
    revert?: boolean;
    onPageChange: CursorOnPageChange;
    /**
     * a table could need to know in wich page it is to display pagination
     */
    page?: number;
    currentSortBy?: string;
    onSortChange: CursorOnSortChange;
};
declare type PaginatedList = OffsetPagination | CursorPagination;
declare type UseListParams<TQuery = Record<string, any>, TItem extends Record<string, any> = Record<string, any>, ListTData = any, ListTVariables = OperationVariables, DeleteTData = any, DeleteTVariables = OperationVariables> = ListProps<TQuery, TItem, ListTData, ListTVariables, DeleteTData, DeleteTVariables> & {};
declare type UseListReturn<TItem = Record<string, any>, TData = any, TVariables = OperationVariables> = {
    refetch: (variables?: Partial<TVariables> | undefined) => Promise<ApolloQueryResult<TData>>;
    onFiltersChange: (filters: Record<string, any>) => void;
    currentFilters: Record<string, any>;
    queryResult: QueryResult<TData, TVariables>;
    list: TItem[];
    pageInfo?: PageInfo;
} & PaginatedList & QueryResult<TData, TVariables>;
/**
 * Hook that manage filtering and pagination for resources list QUERIES.
 * @param {UseListParams} params - all component props
 * @returns {UseListReturn} - use the result to render a custom ListView
 */
declare const useList: <TQuery = Record<string, any>, TItem extends Record<string, any> = Record<string, any>, ListTData = any, ListTVariables = OperationVariables, DeleteTData = any, DeleteTVariables = OperationVariables>({ paginationMode, defaultPerPage, resource, query, queryOptions, defaultFilters, defaultSort, defaultSorting, fields, children, refetchOnDefaultFiltersChange, }: UseListParams<TQuery, TItem, ListTData, ListTVariables, DeleteTData, DeleteTVariables>) => UseListReturn<TItem, ListTData, ListTVariables>;

declare type DataTableValueProps<TItem> = {
    isNumeric?: boolean;
    render?: Renderer<CellProps<any, any>>;
} & CAFieldProps<TItem>;
declare function DataTableValue<TItem = Record<string, any>>(props: DataTableValueProps<TItem>): React__default.ReactElement<DataTableValueProps<TItem>>;

declare type RowClickObject<T> = {
    redirect?: RowClick<T>;
    asModal?: boolean;
};
declare type RowClick<T> = 'show' | 'edit' | false | ((item: T) => string);
declare type DataTableProps<TItem> = Partial<UseListReturn> & Partial<ListProps> & {
    children?: React__default.ReactElement<DataTableValueProps<TItem>>[] | React__default.ReactElement<DataTableValueProps<TItem>>;
    filtersComponent?: React__default.ReactNode;
    moreMenuHeaderComponent?: Renderer<HeaderProps<any>> | string;
    moreMenuComponent?: Renderer<CellProps<any, any>>;
    expandComponent?: React__default.ReactNode;
    paginationComponent?: React__default.ReactNode;
    rowClick?: RowClick<TItem> | RowClickObject<TItem>;
    tableProps?: Omit<TableProps, 'children'>;
    theadProps?: Omit<TableHeadProps, 'children'>;
    tbodyProps?: Omit<TableBodyProps, 'children'>;
    trProps?: Omit<TableRowProps, 'children'>;
    tdProps?: Omit<TableCellProps, 'children'>;
};
declare function DataTable<TItem = Record<string, any>>(props: DataTableProps<TItem>): react_jsx_runtime.JSX.Element;
declare namespace DataTable {
    var displayName: string;
}

declare type UseDataTableReturn = {
    foundedColumns: Column<object>[];
    showBackToTop: boolean;
} & TableInstance<object>;
declare function useDataTable<TItem = Record<string, any>>({ data, list, pageCount, loading, error, onPageChange, onSortChange, total, children, currentFilters, defaultSort, defaultSorting, defaultSortBy, refetch, deleteItemMutation, moreMenuHeaderComponent, moreMenuComponent, hasCreate, hasEdit, hasDelete, hasShow, resource, queryResult, expandComponent, paginationMode, pageInfo, defaultPerPage, ...rest }: DataTableProps<TItem>): UseDataTableReturn;

declare const useSearchParamsAsState: (initialState?: Record<string, string>) => [Record<string, string>, (nextInit?: URLSearchParamsInit | ((prev: URLSearchParams) => URLSearchParamsInit) | undefined) => void];
declare type NewValueType<D> = D | ((latestValue: D) => D);
declare type UrlUpdateType = 'replace' | 'push' | undefined;
declare type UseSearchParam<D, D2 = D> = [D2, (newValue: NewValueType<D>, updateType?: UrlUpdateType) => void];
declare function useSearchParam<D, D2 = D>(name: string, config?: QueryParamConfig<D, D2>): UseSearchParam<D, D2>;

declare type OffsetPaginationParam = {
    page?: number;
    perPage?: number;
    disabled?: boolean;
};
declare type ListGetVariablesParamsBase<TItem extends Record<string, any> = Record<string, any>> = {
    paginationMode: PaginationMode$1;
    resource: string;
};
declare type ListGetVariablesOffsetParams<TItem extends Record<string, any> = Record<string, any>> = ListGetVariablesParamsBase<TItem> & {
    paginationMode: 'offset';
    pagination: OffsetPaginationParam;
    sort: OffsetSortType<TItem>;
    filters: TItem | Record<string, any>;
};
declare type ListGetVariablesCursorParams<TItem extends Record<string, any> = Record<string, any>> = ListGetVariablesParamsBase<TItem> & {
    paginationMode: 'cursor';
    after?: string;
    before?: string;
    first?: number;
    last?: number;
    revert?: boolean;
    sortBy: keyof TItem | string;
    filters: TItem | Record<string, any>;
    resource: string;
};
declare type ListGetVariablesParams<TItem extends Record<string, any> = Record<string, any>> = ListGetVariablesOffsetParams<TItem> | ListGetVariablesCursorParams<TItem>;
declare type GetListResult<TItem = Record<string, any>> = {
    data: TItem[];
    totalCount?: number | undefined | null;
};
declare type PageInfo = {
    hasNextPage?: boolean;
    hasPreviousPage?: boolean;
    startCursor?: string | null;
    endCursor?: string | null;
};
interface ListStrategy<TData = any, TVariables = OperationVariables, TItem = Record<string, any>> {
    getQuery?(resource: string, operation: string, variables?: OperationVariables, fields?: string[], paginationMode?: PaginationMode$1): DocumentNode$1 | TypedDocumentNode<TData, TVariables>;
    getVariables(params: ListGetVariablesParams): TVariables;
    getList: (queryResult: QueryResult<TData, TVariables>, paginationMode: PaginationMode$1) => TItem[];
    getTotal?: (queryResult: QueryResult<TData, TVariables>, paginationMode: PaginationMode$1) => number | undefined | null;
    getPageInfo?: (queryResult: QueryResult<TData, TVariables>) => PageInfo;
}
interface ShowStrategy<TData = any, TFormValues = Record<string, any>, TVariables = OperationVariables, TItem = Record<string, any>> {
    getId: (item: TItem) => string;
    getQuery?(resource: string, operation: string, variables?: OperationVariables, fields?: string[]): DocumentNode$1 | TypedDocumentNode<TData, TVariables>;
    getItem: (queryResult: QueryResult<TData, TVariables>) => TItem;
    getItemVariables: (id: string) => TVariables;
    getMutationVariables?: (id: string, values: TFormValues) => TVariables;
}
interface CreateStrategy<TFormValues = Record<string, any>, TVariables = OperationVariables> {
    getMutationVariables: (values: TFormValues) => TVariables;
}
interface EditStrategy<TData = any, TFormValues = Record<string, any>, TVariables = OperationVariables, TItem = Record<string, any>> {
    getId: (item: TItem) => string;
    getItem: (queryResult: QueryResult<TData, TVariables>) => TItem;
    getItemVariables: (id: string) => TVariables;
    getMutationVariables: (id: string, values: TFormValues) => TVariables;
}
interface DeleteStrategy<TVariables = OperationVariables, TItem = Record<string, any>> {
    getId: (item: TItem) => string;
    getVariables: (id: string) => TVariables;
}
interface Strategy {
    list?: Partial<ListStrategy>;
    show?: Partial<ShowStrategy>;
    create?: Partial<CreateStrategy>;
    edit?: Partial<EditStrategy>;
    delete?: Partial<DeleteStrategy>;
}
interface GlobalStrategy {
    list: ListStrategy;
    show: ShowStrategy;
    create: CreateStrategy;
    edit: EditStrategy;
    delete: DeleteStrategy;
}
declare class DefaultListStrategy implements ListStrategy {
    getQuery(resource: string, operation: string, variables?: OperationVariables, fields?: string[]): DocumentNode$1 | TypedDocumentNode<any, OperationVariables>;
    getVariables(params: ListGetVariablesParams): OperationVariables;
    getList(queryResult: QueryResult<any, OperationVariables>, paginationMode: PaginationMode$1): any;
    getTotal(queryResult: QueryResult<any, OperationVariables>, paginationMode: PaginationMode$1): number | undefined;
    getPageInfo(queryResult: QueryResult<any, OperationVariables>): PageInfo;
}
declare class DefaultShowStrategy implements ShowStrategy {
    getId: ShowStrategy['getId'];
    getQuery(resource: string, operation: string, variables?: OperationVariables, fields?: string[]): DocumentNode$1 | TypedDocumentNode<any, OperationVariables>;
    getItem: ShowStrategy['getItem'];
    getItemVariables: ShowStrategy['getItemVariables'];
    getMutationVariables: ShowStrategy['getMutationVariables'];
}
declare class DefaultCreateStrategy implements CreateStrategy {
    getMutationVariables: CreateStrategy['getMutationVariables'];
}
declare class DefaultEditStrategy implements EditStrategy {
    getId: EditStrategy['getId'];
    getMutationVariables: EditStrategy['getMutationVariables'];
    getItem: EditStrategy['getItem'];
    getItemVariables: EditStrategy['getItemVariables'];
}
declare class DefaultDeleteStrategy implements DeleteStrategy {
    getId: DeleteStrategy['getId'];
    getVariables: DeleteStrategy['getVariables'];
}
declare class DefaultStrategy implements GlobalStrategy {
    list: DefaultListStrategy;
    show: DefaultShowStrategy;
    create: DefaultCreateStrategy;
    edit: DefaultEditStrategy;
    delete: DefaultDeleteStrategy;
}

declare type MiddlewareRedirect = {
    to: To;
    options?: NavigateOptions;
} | string;
declare type MiddlewareFn = (client: ApolloClient<any>) => (true | MiddlewareRedirect) | Promise<true | MiddlewareRedirect>;
declare type Middleware = MiddlewareFn | MiddlewareFn[];
declare type RouteMiddlewareProps = {
    middleware?: Middleware;
    children?: JSX.Element;
};
declare const RouteMiddleware: FC<RouteMiddlewareProps>;

declare type AdminCoreProps = {
    layoutComponent?: React__default.ReactNode;
    modalComponent?: React__default.ReactNode;
    loginComponent?: React__default.ReactNode;
    authProvider?: ClassType<AuthProvider>;
    strategy?: ClassType<GlobalStrategy>;
    routeMiddleware?: Middleware;
    children?: React__default.ReactNode;
};
declare const AdminCore: FC<AdminCoreProps>;

declare type AdminProps<TCache> = AdminCoreProps & {
    client: ApolloClient<TCache>;
    loadingComponent?: React__default.ReactNode;
    i18nProviderProps?: Omit<I18nProviderProps, 'fallback'>;
} & Pick<BrowserRouterProps, 'basename' | 'window'>;
/**
 * Main entry point for the admin panel.
 *
 * It initialize the apollo client, the authProvider, the layout of the application and the routes.
 *
 * @example
 *
 * // basic example
 *
 * import { Admin, Resource } from 'chakra-admin'
 *
 * const App = () => (
 *  <Admin makeClient={createGraphqlClient}>
 *    <Resource name="Company" list={CompanyList} />
 *  </Admin>
 * )
 *
 * // with custom routes
 * import { Admin, Resource } from 'chakra-admin'
 *
 * const App = () => (
 * <Admin makeClient={createGraphqlClient}>
 *  <Resource name="Company" list={CompanyList} />
 *  <Route path="my-custom-route" element={<>My Custom Route</>} />
 * </Admin>
 *
 */
declare const Admin: FC<AdminProps<any>>;

declare type ResourceProps = {
    name: string;
    overrideName?: string;
    routeMiddleware?: Middleware;
    icon?: React__default.ReactNode;
    list?: React__default.ReactNode;
    create?: React__default.ReactNode;
    edit?: React__default.ReactNode;
    show?: React__default.ReactNode;
};
declare const Resource: FC<ResourceProps>;

declare type RequireAuthProps = {
    children?: JSX.Element;
    skip?: boolean;
};
declare const RequireAuth: FC<RequireAuthProps>;

declare type RouteProps = {
    useAdminLayout?: boolean;
} & RouteProps$1;
declare function Route(props: RouteProps): null;

declare const MotionBox: framer_motion.CustomDomComponent<BoxProps>;
declare const MotionFlex: framer_motion.CustomDomComponent<FlexProps>;
declare const MotionHStack: framer_motion.CustomDomComponent<StackProps>;

declare type Props$n = {
    to?: string | Partial<Path>;
} & ButtonProps;
declare const CancelButton: FC<Props$n>;

declare type Props$m = Partial<ListProps> & Partial<UseListReturn> & {
    label?: string | boolean;
    openAsModal?: boolean;
} & ButtonProps & Partial<LinkProps> & Record<string, any>;
declare const CreateButton: FC<Props$m>;

declare type Props$l = Partial<ListProps> & Partial<UseListReturn> & {
    label?: string | boolean;
    openAsModal?: boolean;
} & ButtonProps & Partial<LinkProps>;
declare const EditButton: FC<Props$l>;

declare type GenericMoreMenuButtonProps<Data = any, Variables = OperationVariables> = {
    deleteItemMutation?: DocumentNode | TypedDocumentNode<Data, Variables>;
    onDelete?: ((id: string) => void) | ((id: string) => Promise<void>);
    onDeleteCompleted?: () => void;
    id?: string;
    confirmDialogTitle?: string;
    confirmDialogBody?: string;
    showConfirmDialogOnDelete?: boolean;
    confirmDialogCancelButtonLabel?: string;
    confirmDialogConfirmDeleteButtonLabel?: string;
    resource?: string;
    openShowAsModal?: boolean;
    openEditAsModal?: boolean;
    hideDelete?: boolean;
    hideEdit?: boolean;
    hideShow?: boolean;
    children?: React__default.ReactNode;
} & RouteAvailability & MenuButtonProps;
declare const GenericMoreMenuButton: FC<GenericMoreMenuButtonProps>;

declare type Props$k = ButtonProps & {
    label?: string;
    icon?: any;
};
declare const LogoutButton: FC<Props$k>;

declare type SubmitButtonProps = {
    label?: string;
} & ButtonProps;
declare const SubmitButton: FC<SubmitButtonProps>;

declare type Props$j = {};
declare const UserButton: FC<Props$j>;

declare type Props$i = {};
declare const UserMobileButton: FC<Props$i>;

declare const AUTH_STATE_KEY = "authState";
interface AuthState<UserIdentity = DefaultUserIdentity> {
    isLoggedIn?: boolean;
    authUser?: UserIdentity;
}
declare const authState: recoil.RecoilState<AuthState<DefaultUserIdentity>>;

declare const TOKEN_AUTH_PROVIDER = "chakra-admin_AuthProvider";
declare type SetAuthProviderFunction = (newValue: ClassType<AuthProvider> | undefined) => void;
declare const useAuthProvider: () => AuthProvider | undefined;
declare const useSetAuthProvider: () => SetAuthProviderFunction;

declare type UseAuthUserReturn = {
    initialized: boolean;
    user?: DefaultUserIdentity;
};
declare const useAuthUser: () => {
    initialized: boolean;
    user: DefaultUserIdentity | undefined;
};

declare type UseCheckAuthProps = {
    onAuthCheck?: (isAuthenticated: boolean) => void;
};
declare type UseCheckAuthReturn = {
    initialized: boolean;
    isAuthenticated: boolean;
};
declare const useCheckAuth: (props?: UseCheckAuthProps) => {
    initialized: boolean;
    isAuthenticated: boolean;
};

declare type UseCreateResult<TData = any, TVariables = OperationVariables, TContext = DefaultContext, TCache extends ApolloCache<any> = ApolloCache<any>> = {
    executeMutation: (options?: MutationFunctionOptions<TData, TVariables, TContext, TCache>) => Promise<FetchResult<TData>>;
    mutationResult?: MutationResult<TData>;
    onSubmit: (values: any) => Promise<MutationResult<TData>>;
    defaultValues: any;
};
declare const useCreate: <TData = any, TVariables = OperationVariables, TContext = DefaultContext, TCache extends ApolloCache<any> = ApolloCache<any>>({ mutation, resource, redirect, onSuccess, }: CreateProps) => UseCreateResult<TData, TVariables, TContext, TCache>;

declare type NavigateBehavior = boolean | string | ((data: any) => string | boolean);
declare const navigateBehavior: (navigate: NavigateFunction, redirect: NavigateBehavior, data?: unknown) => void;

declare type EditProps<ItemTData = any, ItemTVariables = OperationVariables, EditTData = any, EditTVariables = OperationVariables> = {
    resource?: string;
    id?: string;
    mutation: DocumentNode | TypedDocumentNode<EditTData, EditTVariables>;
    query: DocumentNode | TypedDocumentNode<ItemTData, ItemTVariables>;
    filtersComponent?: React__default.ReactNode;
    renderingInModal?: boolean;
    layout?: ReactElement<PageLayoutProps, any>;
    onSuccess?: ((data: MutationResult<EditTData>) => void) | ((data: MutationResult<EditTData>) => Promise<void>);
    redirect?: NavigateBehavior;
    children?: React__default.ReactNode;
} & Pick<PageLayoutProps, 'title'>;
declare const Edit: FC<EditProps>;

declare type UseEditResult<TData = any, TVariables = OperationVariables, TItem = Record<string, any>, TContext = DefaultContext, TCache extends ApolloCache<any> = ApolloCache<any>> = {
    executeMutation: (options?: MutationFunctionOptions<TData, TVariables, TContext, TCache>) => Promise<FetchResult<TData>>;
    mutationResult?: MutationResult<TData>;
    onSubmit: (values: any) => Promise<MutationResult<TData>>;
    item?: TItem;
} & QueryResult<TData, TVariables>;
declare const useEdit: <ItemTData = any, ItemTVariables = OperationVariables, EditTData = any, EditTVariables = OperationVariables>({ mutation, resource, query, id, redirect, onSuccess, }: EditProps<ItemTData, ItemTVariables, EditTData, EditTVariables>) => UseEditResult;

declare type ShowProps<TQuery = Record<string, any>, ItemTData = Record<string, any>, ItemTVariables = OperationVariables, EditTData = any, EditTVariables = OperationVariables> = {
    resource?: string;
    id?: string;
    mutation?: DocumentNode | TypedDocumentNode<EditTData, EditTVariables>;
    query: keyof TQuery | (DocumentNode | TypedDocumentNode<ItemTData, ItemTVariables>);
    fields?: NestedKeyOf<Required<ItemTData>>[];
    renderingInModal?: boolean;
    layout?: ReactElement<PageLayoutProps, any>;
    toolbarComponent?: React__default.ReactNode;
    children?: React__default.ReactNode;
    queryOptions?: QueryHookOptions<ItemTData, ItemTVariables>;
} & Pick<PageLayoutProps, 'title'>;
declare function Show<TQuery = Record<string, any>, TItem = Record<string, any>>(props: ShowProps<TQuery, TItem>): React__default.FunctionComponentElement<any>;

declare type UseShowResult<TData = any, TVariables = OperationVariables, TItem = Record<string, any>, TContext = DefaultContext, TCache extends ApolloCache<any> = ApolloCache<any>> = {
    executeMutation: (options?: MutationFunctionOptions<TData, TVariables, TContext, TCache>) => Promise<FetchResult<TData>>;
    mutationResult?: MutationResult<TData>;
    onSubmit: (values: any) => Promise<MutationResult<TData>>;
    item?: TItem;
} & QueryResult<TData, TVariables>;
declare const useShow: <ItemTData = any, ItemTVariables = OperationVariables, ShowTData = any, ShowTVariables = OperationVariables>({ mutation, resource, query, id, fields, children, queryOptions, }: ShowProps<ItemTData, ItemTVariables, ShowTData, ShowTVariables, OperationVariables>) => UseShowResult;

declare type UseDeleteWithConfirmOptions<Data = any, Variables = OperationVariables> = {
    onDelete?: ((id: string) => void) | ((id: string) => Promise<void>);
    deleteItemMutation?: DocumentNode$1 | TypedDocumentNode<Data, Variables>;
    onDeleteCompleted?: () => void;
};
declare type UseDeleteWithConfirmReturn = {
    deleting: boolean;
    onDeleteItem: (id?: string) => Promise<void>;
} & UseDisclosureReturn;
declare function useDeleteWithConfirm(options: UseDeleteWithConfirmOptions): UseDeleteWithConfirmReturn;

declare type PaginationMode = 'cursor' | 'offset';
declare type GQLOperation<TOperations = Record<string, any>, TData = any, TVariables = OperationVariables> = keyof TOperations | (DocumentNode$1 | TypedDocumentNode<TData, TVariables>);
declare type OperationType = 'query' | 'mutation';
declare type GqlGenerator<TData = any, TVariables = OperationVariables> = (resource: string, operation: string, variables?: OperationVariables, fields?: string[], paginationMode?: PaginationMode) => DocumentNode$1 | TypedDocumentNode<TData, TVariables>;

declare const EMPTY_QUERY: DocumentNode$1;
declare type GetAdditionalFields = () => Fields;
declare function generateFields(fields?: string[], getAdditionalFields?: GetAdditionalFields): Fields;
declare type UseGQLBuilderParams<TOperations = Record<string, any>, TData = any, TVariables = OperationVariables> = {
    resource?: string;
    type: OperationType;
    operation: GQLOperation<TOperations, TData, TVariables>;
    variables?: TVariables;
    operationName?: string;
    generateGql: GqlGenerator<TData, TVariables>;
    children?: React__default.ReactNode;
    additionalFields?: string[];
    paginationMode?: PaginationMode;
};
declare type UseGQLBuilderResult<TData = any, TVariables = OperationVariables> = {
    initialized: boolean;
    operation?: DocumentNode$1 | TypedDocumentNode<TData, TVariables>;
    type: OperationType;
    selectionSet: string[];
};
declare function useGqlBuilder<TOperations = Record<string, any>, TData = any, TVariables = OperationVariables>({ operation, resource, generateGql, variables, type, children, additionalFields, paginationMode, }: UseGQLBuilderParams<TOperations, TData, TVariables>): UseGQLBuilderResult<TData, TVariables>;

/**
 * Check if the device is a mobile or not
 *
 * @returns {boolean}
 */
declare const isMobile: () => boolean;

declare function useLocalStorage<T>(key: string, initialValue: T): readonly [T, (value: T | ((val: T) => T)) => void];

declare type CreateProps<TData = any, TVariables = OperationVariables> = {
    resource?: string;
    mutation: DocumentNode | TypedDocumentNode<TData, TVariables>;
    filtersComponent?: React__default.ReactNode;
    renderingInModal?: boolean;
    layout?: ReactElement<PageLayoutProps, any>;
    onSuccess?: ((data: MutationResult<TData>) => void) | ((data: MutationResult<TData>) => Promise<void>);
    redirect?: NavigateBehavior;
    children?: React__default.ReactNode;
} & Pick<PageLayoutProps, 'title'>;
declare const Create: FC<CreateProps>;

declare type Props$h = Partial<ShowProps>;
declare const ShowToolbar: FC<Props$h>;

declare type Props$g = {
    propsOverride: any;
    children?: React__default.ReactNode;
};
declare const TreeRenderer: FC<Props$g>;

declare type Props$f = {
    value?: string;
    locales?: string | string[];
    intlOptions?: Intl.DateTimeFormatOptions;
} & TextProps;
declare const DateField: FC<Props$f>;

declare type StatusOptions = {
    statusColor?: ColorProps['color'];
    textColorScheme?: ThemingProps<'Text'>['colorScheme'];
    textColor?: ColorProps['color'];
    label?: React__default.ReactNode;
};
declare type StatusFieldProps<TItem extends object> = {
    statuses?: Record<string | number, StatusOptions>;
} & Partial<CAFieldProps<BoxProps, TItem>> & BoxProps;
declare function StatusField<TItem extends object = Record<string, any>>({ statuses, ...rest }: StatusFieldProps<TItem>): react_jsx_runtime.JSX.Element;

declare type ArrayFieldProps<TItem = Record<string, any>> = {
    entries?: TItem[];
    emptyComponent?: React__default.ReactNode;
} & StackProps;
declare const ArrayField: FC<ArrayFieldProps>;

declare type BaseFormProps = {
    children?: React__default.ReactNode;
    defaultValues?: any;
    resource?: string;
    renderingInModal?: boolean;
} & Partial<UseCreateResult | UseEditResult> & ChakraProps;
declare const BaseForm: FC<BaseFormProps>;
declare type BaseFormPartProps = {
    children: React__default.ReactNode;
    renderingInModal?: boolean;
};

declare type QueryProps<TQuery = Record<string, any>, TData = any, TVariables = OperationVariables> = Partial<Omit<UseGQLBuilderParams<TQuery, TData, TVariables>, 'operation' | 'type' | 'additionaFields'>> & {
    type?: 'list' | 'show';
    query: GQLOperation<TQuery, TData, TVariables>;
    fields?: NestedKeyOf<Required<TData>>[];
    paginationMode?: PaginationMode$1;
};
declare function Query<TQuery = Record<string, any>, TData = any, TVariables = OperationVariables>({ query, type, fields, paginationMode, ...props }: QueryProps<TQuery, TData, TVariables>): react_jsx_runtime.JSX.Element;

declare type BaseInputProps = {
    source: string;
    onChange?: (newValue: string) => void;
    value?: string;
    label?: React__default.ReactNode;
    helperText?: React__default.ReactNode;
    register?: UseFormRegister<any>;
    unregister?: UseFormUnregister<any>;
    control?: Control;
    parse?: <Input = any, Return = any>(inputValue: Input) => Return;
    format?: <Input = any, Return = any>(inputValue: Input) => Return;
} & Omit<InputProps$1, 'value' | 'onChange'>;

declare type FilterInputProps = {
    alwaysOn?: boolean;
    showFormControl?: boolean;
};

declare type InputProps = FilterInputProps & BaseInputProps & InputProps$1;
declare const Input: FC<InputProps>;

interface Item {
    label: string;
    value: string;
}

interface CUIAutoCompleteProps<T extends Item> extends UseComboboxProps<T> {
    items: T[];
    placeholder: string;
    label: string;
    highlightItemBg?: string;
    onCreateItem?: (item: T) => void;
    optionFilterFunc?: ((items: T[], inputValue: string) => T[]) | ((items: T[], inputValue: string) => Promise<T[]>);
    itemRenderer?: (item: T) => string | JSX.Element;
    labelStyleProps?: FormLabelProps;
    inputStyleProps?: InputProps$1;
    toggleButtonStyleProps?: ButtonProps;
    listStyleProps?: BoxProps;
    listItemStyleProps?: BoxProps;
    emptyState?: (inputValue: string) => React.ReactNode;
    selectedIconProps?: Omit<IconProps, 'name'> & {
        icon: IconProps['name'] | React.ComponentType;
    };
    icon?: ComponentWithAs<'svg', IconProps>;
    hideToggleButton?: boolean;
    createItemRenderer?: (value: string) => string | JSX.Element;
    disableCreateItem?: boolean;
}

declare type AutocompleteInputProps<TQuery = Record<string, any>, TItem extends Record<string, any> = Record<string, any>, ListTData = any, ListTVariables = OperationVariables> = Omit<InputProps, 'source' | 'onChange'> & Omit<CUIAutoCompleteProps<Item>, 'placeholder' | 'items' | 'onChange'> & {
    onChange?: (newValue: string, item: any) => void;
    showEmptyState?: boolean;
    /**
     * The query to execute to get the items
     */
    createMutation?: DocumentNode;
    inputValueToCreateVariables?: (inputValue: string) => Record<string, any>;
    inputValueToFilters?: (value: string) => Record<string, any>;
    emptyLabel?: string;
    dataItemToAutocompleteItem?: (data: Record<string, any>, index: number) => Item & {
        [x: string]: any;
    };
    filterResult?: (items: Item) => boolean;
    resetList?: number;
    first?: number;
    last?: number;
    revert?: boolean;
    sortBy?: string;
    page?: number;
    sort?: OffsetSortType<TItem>;
    perPage?: number;
} & Omit<CAInputProps, 'onChange'> & Pick<ListProps, 'paginationMode' | 'query' | 'queryOptions' | 'resource' | 'basePath' | 'fields'>;
declare const Autocomplete: FC<AutocompleteInputProps>;
declare const AutocompleteWithCreate: FC<AutocompleteInputProps>;
/**
 * Autocomplete input component
 */
declare const AutocompleteInput: FC<AutocompleteInputProps>;

declare type SelectInputProps<TQuery = Record<string, any>, TData extends FieldValues = any, TQueryData = any, TQueryVariables = OperationVariables> = FilterInputProps & CAInputProps<TData> & SelectProps & Partial<QueryProps<TQuery, TQueryData, TQueryVariables>> & {
    showEmpty?: boolean;
    emptyLabel?: string;
    getOption?: (record: TQueryData) => {
        value: string;
        label: string;
    };
};
declare function SelectInput<TQuery = Record<string, any>, TData extends FieldValues = any, TQueryData = any, TQueryVariables = OperationVariables>({ onChange: onChangeProp, source, alwaysOn, register, label, query, fields, resource, variables, operationName, generateGql, children, required, min, max, maxLength, minLength, pattern, validate, placeholder, shouldUnregister, getOption, value, showEmpty, emptyLabel, control, paginationMode, ...rest }: SelectInputProps<TQuery, TData, TQueryData, TQueryVariables> & Record<string, any>): react_jsx_runtime.JSX.Element;

declare type SingleImageInputProps<TItem extends FieldValues = Record<string, any>> = {} & CAInputProps<TItem> & BoxProps;
/**
 *
 * WIP: Component that add a single image to the form data.
 *
 * @example
 *
 * <SingleImageInput source="image" />
 */
declare function SingleImageInput<TItem extends FieldValues = Record<string, any>>({ source, label, resource, required, min, max, maxLength, minLength, pattern, validate, valueAsNumber, valueAsDate, value, setValueAs, shouldUnregister, onChange, onBlur, disabled, deps, ...rest }: SingleImageInputProps<TItem>): react_jsx_runtime.JSX.Element;

declare type SingleFileInputProps<TItem extends FieldValues = Record<string, any>> = {} & CAInputProps<TItem> & BoxProps;
/**
 *
 * WIP: Component that add a single image to the form data.
 *
 * @example
 *
 * <SingleImageInput source="image" />
 */
declare function SingleFileInput<TItem extends FieldValues = Record<string, any>>({ source, label, resource, required, min, max, maxLength, minLength, pattern, validate, valueAsNumber, valueAsDate, value, setValueAs, shouldUnregister, onChange, onBlur, disabled, deps, ...rest }: SingleFileInputProps<TItem>): react_jsx_runtime.JSX.Element;

declare function CalendarWeek(): react_jsx_runtime.JSX.Element;
declare type DateInputProps<TItem extends FieldValues> = {
    locale?: Locale;
    placeholder?: string;
} & CAInputProps<TItem> & BoxProps;
declare function DateInput<TItem extends FieldValues = Record<string, any>>({ source, label, resource, required, min, max, maxLength, minLength, pattern, validate, valueAsNumber, valueAsDate, value, setValueAs, shouldUnregister, onChange, onBlur, disabled, deps, locale, placeholder, ...rest }: DateInputProps<TItem>): react_jsx_runtime.JSX.Element;

declare type ColorInputProps<TItem extends FieldValues = Record<string, any>> = {
    placeholder?: string;
} & CAInputProps<TItem> & BoxProps;
/**
 *
 * WIP: Component for choosing a color.
 *
 * @example
 *
 * <ColorInput source="color" />
 */
declare function ColorInput<TItem extends FieldValues = Record<string, any>>({ source, label, resource, required, min, max, maxLength, minLength, pattern, validate, valueAsNumber, valueAsDate, value, setValueAs, shouldUnregister, onChange, onBlur, disabled, deps, placeholder, ...rest }: ColorInputProps<TItem>): react_jsx_runtime.JSX.Element;

declare type ArrayInputProps<TItem extends FieldValues = Record<string, any>> = {
    emptyComponent?: React__default.ReactNode;
    topToolbar?: React__default.ReactNode;
    bottomToolbar?: React__default.ReactNode;
} & CAInputProps<TItem>;
/**
 * WIP!
 */
declare const ArrayInput: FC<ArrayInputProps>;

declare type DatetimeInputProps = {
    inputProps?: InputProps$1;
} & Omit<DatetimepickerProps, 'inputProps'>;
declare const DatetimeInputBase: FC<DatetimeInputProps>;
declare const DatetimeInput: {
    <TItemField extends react_hook_form.FieldValues = Record<string, any>>(props: {
        source: keyof TItemField;
        label?: string | undefined;
        resource?: string | undefined;
    } & Partial<{
        required: string | react_hook_form.ValidationRule<boolean>;
        min: react_hook_form.ValidationRule<string | number>;
        max: react_hook_form.ValidationRule<string | number>;
        maxLength: react_hook_form.ValidationRule<number>;
        minLength: react_hook_form.ValidationRule<number>;
        pattern: react_hook_form.ValidationRule<RegExp>;
        validate: react_hook_form.Validate<react_hook_form.PathValue<TItemField, react_hook_form.Path<TItemField>>> | Record<string, react_hook_form.Validate<react_hook_form.PathValue<TItemField, react_hook_form.Path<TItemField>>>>;
        valueAsNumber: boolean;
        valueAsDate: boolean;
        value: react_hook_form.PathValue<TItemField, react_hook_form.Path<TItemField>>;
        setValueAs: (value: any) => any;
        shouldUnregister?: boolean | undefined;
        onChange?: ((event: any) => void) | undefined;
        onBlur?: ((event: any) => void) | undefined;
        disabled: boolean;
        deps: string | string[];
    }>): react_jsx_runtime.JSX.Element;
    displayName: string;
};

declare type MenuCollapseViewProps = {
    id?: string;
    label?: string;
    additionalElement?: React__default.ReactNode;
    isOpen?: boolean;
    onToggle?: () => void;
} & BoxProps;
declare const MenuCollapseView: FC<MenuCollapseViewProps>;
declare type MenuCollapseProps = Omit<MenuCollapseViewProps, 'onToggle' | 'isOpen'> & UseDisclosureProps;
declare const MenuCollapse: FC<MenuCollapseProps>;
declare type StoredMenuCollapseProps = Omit<MenuCollapseViewProps, 'id' | 'onToggle' | 'isOpen'> & {
    id: string;
    defaultIsOpen?: boolean;
};
declare const StoredMenuCollapse: FC<StoredMenuCollapseProps>;

declare type Props$e = {
    to: string;
    label: string;
    icon?: React__default.ReactElement;
} & ButtonProps;
declare const MenuItemLink: FC<Props$e>;

declare type MenuSearchInputProps = {
    placeholder?: string;
    onChange?: (e: React__default.ChangeEvent<HTMLInputElement>) => void;
    value?: string;
} & InputGroupProps;
declare const MenuSearchInput: FC<MenuSearchInputProps>;

declare type Props$d = {} & MenuSearchInputProps;
declare const MenuSearch: FC<Props$d>;

declare type NavMenuProps = {
    onItemClick?: () => void;
    children?: React__default.ReactNode;
};
declare const NavMenu: FC<NavMenuProps>;

declare type Props$c = {
    title?: string;
    icon?: React__default.ReactNode;
} & BoxProps;
declare const Sidebar: FC<Props$c>;

declare type Props$b = {
    icon: React__default.ReactNode;
    title?: string;
} & BoxProps;
declare const SidebarTitle: FC<Props$b>;

declare type Props$a = {
    isCompressed: boolean;
} & Omit<IconButtonProps, 'aria-label'>;
declare const ToggleSizeButton: FC<Props$a>;

declare type RouteLayoutProps = {
    sidebar?: React__default.ReactNode;
    showOfflineAlert?: boolean;
};
declare const RouteLayout: FC<RouteLayoutProps>;

declare type Props$9 = {};
declare const MobileTopBar: FC<Props$9>;

declare type Props$8 = {
    title?: string;
    icon?: string;
    children?: React__default.ReactNode;
};
declare const MobileTopBarLight: FC<Props$8>;

declare type Props$7 = {} & BoxProps;
declare const OfflineAlert: FC<Props$7>;

declare type PageTitleProps = {
    label?: string;
    icon?: As | undefined;
    boxComponent?: React__default.ReactNode;
    renderingInModal?: boolean;
    loading?: boolean;
    resource?: string;
    data?: any;
    error?: any;
    record?: any;
} & BoxProps;
declare const PageTitle: FC<PageTitleProps>;

declare const ShadowedBox: FC<BoxProps & {
    [prop: string]: any;
}>;

declare type Props$6 = Omit<DrawerProps, 'children'> & {};
declare const UserSettingsDrawer: FC<Props$6>;

declare type Props$5 = {};
declare const Empty: FC<Props$5>;

declare type FiltersProps = Partial<UseListReturn & ListProps> & {
    children?: React__default.ReactNode;
    filtersTitle?: string;
    filtersButtonLabel?: string;
    removeFiltersButtonLabel?: string;
    containerProps?: BoxProps;
};
declare const Filters: FC<FiltersProps>;

declare function List<TQuery = Record<string, any>, TItem extends Record<string, any> = Record<string, any>>(props: ListProps<TQuery, TItem>): React__default.FunctionComponentElement<any>;
declare namespace List {
    var displayName: string;
}

declare type Props$4 = Partial<ListProps>;
declare const ListToolbar: FC<Props$4>;

declare type MobileDataTableProps<TItem> = Partial<UseListReturn> & Partial<ListProps> & {
    children?: React__default.ReactElement<DataTableValueProps<TItem>>[];
    filtersComponent?: React__default.ReactNode;
    moreMenuHeaderComponent?: Renderer<HeaderProps<any>> | string;
    moreMenuComponent?: Renderer<CellProps<any, any>>;
    tableProps: Omit<TableProps, 'children'>;
    theadProps: Omit<TableHeadProps, 'children'>;
    tbodyProps: Omit<TableBodyProps, 'children'>;
    trProps: Omit<TableRowProps, 'children'>;
    tdProps: Omit<TableCellProps, 'children'>;
};
declare function MobileDataTable<TItem = Record<string, any>>(props: MobileDataTableProps<TItem>): react_jsx_runtime.JSX.Element;

declare type Props$3 = {};
declare const MoreMenuHeader: FC<Props$3>;

declare type PaginationProps = {
    page: Row<object>[];
    paginationMode: PaginationMode$1;
    showBackToTop?: boolean;
    pageCount: number;
    pageSize: number;
    pageIndex: number;
    pageOptions: number[];
    canPreviousPage: boolean;
    canNextPage: boolean;
    gotoPage: (updater: ((pageIndex: number) => number) | number) => void;
    previousPage: () => void;
    nextPage: () => void;
    setPageSize: (pageSize: number) => void;
    backToTop: () => void;
    fetching?: boolean;
    totalRows?: number;
};
declare const Pagination: FC<PaginationProps>;

declare type Props$2 = {
    applicationImageUrl?: string;
    applicationIcon?: string;
};
declare const Login: FC<Props$2>;

declare type Props$1 = {
    title?: string;
    caption?: string;
};
declare const LoginForm: FC<Props$1>;

declare const DrawerBody: FC<ModalBodyProps>;

declare type Props = {
    title?: string;
    subtitle?: React__default.ReactNode;
} & ModalHeaderProps;
declare const DrawerHeader: FC<Props>;

declare type ModalRouteLayoutProps = {};
declare const ModalRouteLayout: FC<ModalRouteLayoutProps>;

declare type DeleteModalProps = {
    resource?: string;
    id?: string;
    onDeleteItem: ((id?: string) => void) | ((id?: string) => Promise<void>);
    deleting: boolean;
    title?: string;
    description?: string;
    confirmDeleteButtonLabel?: string;
} & Omit<ModalProps, 'children'>;
declare const DeleteModal: FC<DeleteModalProps>;

export { ADMIN_STATE_KEY, AUTH_STATE_KEY, Admin, AdminCore, AdminCoreProps, AdminProps, AdminState, ArrayField, ArrayFieldProps, ArrayInput, ArrayInputProps, AuthProvider, AuthState, Autocomplete, AutocompleteInput, AutocompleteInputProps, AutocompleteWithCreate, BaseForm, BaseFormPartProps, BaseInputProps, BaseListPagination, CalendarWeek, CancelButton, ClassType, ColorInput, Create, CreateButton, CreateProps, CreateStrategy, CursorOnPageChange, CursorOnPageChangeParams, CursorOnSortChange, CursorPagination, CursorsOnSortChangeParams, DEFAULT_PER_PAGE, DataTable, DataTableProps, DataTableValue, DataTableValueProps, DateField, DateInput, DatetimeInput, DatetimeInputBase, DatetimeInputProps, DefaultCreateStrategy, DefaultDeleteStrategy, DefaultEditStrategy, DefaultListStrategy, DefaultShowStrategy, DefaultStrategy, DefaultUserIdentity, DeleteModal, DeleteModalProps, DeleteStrategy, DrawerBody, DrawerHeader, EMPTY_QUERY, Edit, EditButton, EditProps, EditStrategy, Empty, FilterInputProps, Filters, FiltersProps, GenericMoreMenuButton, GenericMoreMenuButtonProps, GetListResult, GlobalStrategy, Input, InputProps, List, ListGetVariablesCursorParams, ListGetVariablesOffsetParams, ListGetVariablesParams, ListGetVariablesParamsBase, ListProps, ListStrategy, ListToolbar, Login, LoginForm, LogoutButton, MenuCollapse, MenuCollapseProps, MenuCollapseView, MenuCollapseViewProps, MenuItemLink, MenuSearch, MenuSearchInput, MenuSearchInputProps, Middleware, MiddlewareFn, MiddlewareRedirect, MobileDataTable, MobileDataTableProps, MobileTopBar, MobileTopBarLight, ModalRouteLayout, ModalRouteLayoutProps, MoreMenuHeader, MotionBox, MotionFlex, MotionHStack, NavMenu, NavMenuProps, NavigateBehavior, NewValueType, OfflineAlert, OffsetOnPageChange, OffsetOnPageChangeParams, OffsetOnSortChange, OffsetPagination, OffsetPaginationParam, OffsetSortDirection, OffsetSortType, OnPageChange, OnPageChangeParams, OnSortChange, PageInfo, PageLayout, PageLayoutProps, PageTitle, PageTitleProps, PaginatedList, Pagination, PaginationMode$1 as PaginationMode, PaginationProps, QP_AFTER, QP_BEFORE, QP_FILTERS_PREFIX, QP_FIRST, QP_LAST, QP_PAGE, QP_PER_PAGE, QP_REVERT, QP_SORT_BY, QP_SORT_PREFIX, Query, QueryProps, RegisteredResources, RequireAuth, Resource, ResourceProps, Route, RouteAvailability, RouteLayout, RouteLayoutProps, RouteMiddleware, RouteProps, RowClick, RowClickObject, SelectInput, SelectInputProps, ShadowedBox, Show, ShowProps, ShowStrategy, ShowToolbar, Sidebar, SidebarTitle, SingleFileInput, SingleImageInput, StatusField, StatusFieldProps, StatusOptions, StoredMenuCollapse, StoredMenuCollapseProps, Strategy, SubmitButton, TOKEN_AUTH_PROVIDER, TOKEN_GLOBAL_STRATEGY, ToggleSizeButton, TreeRenderer, UrlUpdateType, UseAuthUserReturn, UseCheckAuthProps, UseCheckAuthReturn, UseCreateResult, UseDataTableReturn, UseEditResult, UseGQLBuilderParams, UseGQLBuilderResult, UseListParams, UseListReturn, UseSearchParam, UseShowResult, UserButton, UserMobileButton, UserSettingsDrawer, VERSION_STATE_KEY, adminState, authState, generateFields, isMobile, navigateBehavior, registeredIcons, removeListProps, useAdminCore, useAdminState, useAdminStateValue, useAuthProvider, useAuthUser, useCheckAuth, useCreate, useDataTable, useDeleteWithConfirm, useEdit, useGetResourceLabel, useGlobalStrategy, useGqlBuilder, useList, useLocalStorage, useResetAdminState, useResetVersionState, useSearchParam, useSearchParamsAsState, useSetAdminState, useSetAuthProvider, useSetGlobalStrategy, useSetVersionState, useShow, useVersion, useVersionState, useVersionStateValue, versionState };
